==> haskell-text-metrics-0.3.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-metrics
version:              0.3.0
visibility:           public
id:                   text-metrics-0.3.0-Ge037oX7481CDXYFAfLFn2
key:                  text-metrics-0.3.0-Ge037oX7481CDXYFAfLFn2
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  c10d108d8a73a8809b74c9b93e6399bc
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-8.10.1/site-local/text-metrics-0.3.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/text-metrics-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/text-metrics-0.3.0
hs-libraries:         HStext-metrics-0.3.0-Ge037oX7481CDXYFAfLFn2
depends:
    base-4.14.0.0 containers-0.6.2.1 text-1.2.3.2
    vector-0.12.1.2-8A0MDgLPPVcWTXsA8tpNg

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-metrics-0.3.0-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-metrics
version:              0.3.0
visibility:           public
id:                   text-metrics-0.3.0-9b8PcddTliMG8q1LQRbltx
key:                  text-metrics-0.3.0-9b8PcddTliMG8q1LQRbltx
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  e1d471463d07baf1864dd191f785764d
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-8.10.1/site-local/text-metrics-0.3.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/text-metrics-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/text-metrics-0.3.0
hs-libraries:         HStext-metrics-0.3.0-9b8PcddTliMG8q1LQRbltx
depends:
    base-4.14.0.0 containers-0.6.2.1 text-1.2.3.2
    vector-0.12.1.2-KotqULZza37AeFlfLxbJau

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
